==> owncloud-10.0.7.tgz: owncloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "el mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "el año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "segundos atrás",
    "None" : "Ninguno",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "App directory already exists" : "El directorio de la app ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear el directorio para la app. Corregí los permisos. %s",
    "No source specified when installing app" : "No se especificó el origen al instalar la app",
    "No href specified when installing app from http" : "No se especificó href al instalar la app",
    "No path specified when installing app from local file" : "No se especificó PATH al instalar la app desde el archivo local",
    "Archives of type %s are not supported" : "No hay soporte para archivos de tipo %s",
    "Failed to open archive when installing app" : "Error al abrir archivo mientras se instalaba la app",
    "App does not provide an info.xml file" : "La app no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "No puede ser instalada la app por tener código no autorizado",
    "App can't be installed because it is not compatible with this version of ownCloud" : "No se puede instalar la app porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La app no se puede instalar porque contiene la etiqueta <shipped>true</shipped> que no está permitida para apps no distribuidas",
    "Apps" : "Apps",
    "General" : "General",
    "Storage" : "Almacenamiento",
    "Security" : "Seguridad",
    "Encryption" : "Encriptación",
    "Sharing" : "Compartiendo",
    "Search" : "Buscar",
    "Updates" : "Actualizaciones",
    "%s enter the database username." : "%s Entrá el usuario de la base de datos",
    "%s enter the database name." : "%s Entrá el nombre de la base de datos.",
    "%s you may not use dots in the database name" : "%s no podés usar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña no son válidos",
    "DB Error: \"%s\"" : "Error DB: \"%s\"",
    "Offending command was: \"%s\"" : "El comando no comprendido es: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tenés que ingresar una cuenta existente o el administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "El comando no comprendido es: \"%s\", nombre: \"%s\", contraseña: \"%s\"",
    "PostgreSQL username and/or password not valid" : "Nombre de usuario o contraseña PostgradeSQL inválido.",
    "Set an admin username." : "Configurar un nombre de administrador.",
    "Set an admin password." : "Configurar una contraseña de administrador.",
    "%s shared »%s« with you" : "%s compartió \"%s\" con vos",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoría \"%s\"",
    "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
    "A valid password must be provided" : "Debe ingresar una contraseña válida",
    "Help" : "Ayuda",
    "Settings" : "Configuración",
    "Users" : "Usuarios",
    "web services under your control" : "servicios web sobre los que tenés control",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error al autenticar",
    "Token expired. Please reload page." : "Token expirado. Por favor, recargá la página."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "el mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "el año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "segundos atrás",
    "None" : "Ninguno",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "App directory already exists" : "El directorio de la app ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear el directorio para la app. Corregí los permisos. %s",
    "No source specified when installing app" : "No se especificó el origen al instalar la app",
    "No href specified when installing app from http" : "No se especificó href al instalar la app",
    "No path specified when installing app from local file" : "No se especificó PATH al instalar la app desde el archivo local",
    "Archives of type %s are not supported" : "No hay soporte para archivos de tipo %s",
    "Failed to open archive when installing app" : "Error al abrir archivo mientras se instalaba la app",
    "App does not provide an info.xml file" : "La app no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "No puede ser instalada la app por tener código no autorizado",
    "App can't be installed because it is not compatible with this version of ownCloud" : "No se puede instalar la app porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La app no se puede instalar porque contiene la etiqueta <shipped>true</shipped> que no está permitida para apps no distribuidas",
    "Apps" : "Apps",
    "General" : "General",
    "Storage" : "Almacenamiento",
    "Security" : "Seguridad",
    "Encryption" : "Encriptación",
    "Sharing" : "Compartiendo",
    "Search" : "Buscar",
    "Updates" : "Actualizaciones",
    "%s enter the database username." : "%s Entrá el usuario de la base de datos",
    "%s enter the database name." : "%s Entrá el nombre de la base de datos.",
    "%s you may not use dots in the database name" : "%s no podés usar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña no son válidos",
    "DB Error: \"%s\"" : "Error DB: \"%s\"",
    "Offending command was: \"%s\"" : "El comando no comprendido es: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tenés que ingresar una cuenta existente o el administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "El comando no comprendido es: \"%s\", nombre: \"%s\", contraseña: \"%s\"",
    "PostgreSQL username and/or password not valid" : "Nombre de usuario o contraseña PostgradeSQL inválido.",
    "Set an admin username." : "Configurar un nombre de administrador.",
    "Set an admin password." : "Configurar una contraseña de administrador.",
    "%s shared »%s« with you" : "%s compartió \"%s\" con vos",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoría \"%s\"",
    "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
    "A valid password must be provided" : "Debe ingresar una contraseña válida",
    "Help" : "Ayuda",
    "Settings" : "Configuración",
    "Users" : "Usuarios",
    "web services under your control" : "servicios web sobre los que tenés control",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error al autenticar",
    "Token expired. Please reload page." : "Token expirado. Por favor, recargá la página.",
    "See %s" : "Ver %s",
    "A safe home for all your data" : "Un lugar seguro para todos sus datos",
    "Storage is temporarily not available" : "El repositorio no está disponible temporalmente",
    "Unknown user" : "Usuario desconocido",
    "Imprint" : "Imprint",
    "__language_name__" : "Castellano (Argentina)"
},
"nplurals=2; plural=(n != 1);");
